@@ -1,7 +1,7 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 1998-2000, 2007, 2009-2014, 2019 Free Software Foundation,
-    Inc.
+    Copyright (C) 1998-2000, 2007, 2009-2014, 2019-2020 Free Software
+    Foundation, Inc.
 
     crc32.h
 
