@@ -1,7 +1,7 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2000, 2005, 2007, 2009-2014, 2019 Free Software Foundation,
-    Inc.
+    Copyright (C) 2000, 2005, 2007, 2009-2014, 2019-2020 Free Software
+    Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -106,7 +106,7 @@ void ped_assert (const char* cond_text,
         /* Throw the exception */
         ped_exception_throw (
                 PED_EXCEPTION_BUG,
-                PED_EXCEPTION_FATAL,
+                PED_EXCEPTION_CANCEL,
                 _("Assertion (%s) at %s:%d in function %s() failed."),
                 cond_text, file, line, function);
         abort ();
