@@ -1,7 +1,7 @@
 /*
     ext2.h -- ext2 header
-    Copyright (C) 1998-2000, 2007, 2009-2014, 2019 Free Software Foundation,
-    Inc.
+    Copyright (C) 1998-2000, 2007, 2009-2014, 2019-2020 Free Software
+    Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
