@@ -1,6 +1,7 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2000, 2007, 2009-2014, 2019 Free Software Foundation, Inc.
+    Copyright (C) 2000, 2007, 2009-2014, 2019-2020 Free Software Foundation,
+    Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,16 +36,17 @@
 PedGeometry*
 ntfs_probe (PedGeometry* geom)
 {
-	char	*buf = alloca (geom->dev->sector_size);
+	uint8_t *buf = alloca(geom->dev->sector_size);
 	PedGeometry *newg = NULL;
 
 	if (!ped_geometry_read(geom, buf, 0, 1))
 		return 0;
 
-	if (strncmp (NTFS_SIGNATURE, buf + 3, strlen (NTFS_SIGNATURE)) == 0)
-		newg = ped_geometry_new (geom->dev, geom->start,
-					 PED_LE64_TO_CPU (*(uint64_t*)
-						 	  (buf + 0x28)));
+	if (strncmp (NTFS_SIGNATURE, ((char *)buf + 3), strlen (NTFS_SIGNATURE)) == 0) {
+		uint64_t length;
+		memcpy(&length, buf + 0x28, sizeof(uint64_t));
+		newg = ped_geometry_new (geom->dev, geom->start, length);
+	}
 	return newg;
 }
 
