@@ -1,7 +1,7 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2004-2005, 2007, 2009-2014, 2019 Free Software Foundation,
-    Inc.
+    Copyright (C) 2004-2005, 2007, 2009-2014, 2019-2020 Free Software
+    Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -173,7 +173,7 @@ hfsc_cache_add_extent(HfsCPrivateCache* cache, uint32_t start, uint32_t length,
 	return ext;
 }
 
-HfsCPrivateExtent*
+HfsCPrivateExtent* _GL_ATTRIBUTE_PURE
 hfsc_cache_search_extent(HfsCPrivateCache* cache, uint32_t start)
 {
 	HfsCPrivateExtent*	ret;
